import request from '@/utils/request'

// 查询护理人员列表
export function listNurses(query) {
  return request({
    url: '/care/nurses/list',
    method: 'get',
    params: query
  })
}

// 查询护理人员详细
export function getNurses(nurseId) {
  return request({
    url: '/care/nurses/' + nurseId,
    method: 'get'
  })
}

// 新增护理人员
export function addNurses(data) {
  return request({
    url: '/care/nurses',
    method: 'post',
    data: data
  })
}

// 修改护理人员
export function updateNurses(data) {
  return request({
    url: '/care/nurses',
    method: 'put',
    data: data
  })
}

// 删除护理人员
export function delNurses(nurseId) {
  return request({
    url: '/care/nurses/' + nurseId,
    method: 'delete'
  })
}
// 查询所有的公司信息
export function listAllCompany(query) {
  return request({
    url: '/care/companies/listAll',
    method: 'get'
  })
}
// 密码重置
export function resetPassword(userId) {
  return request({
    url: '/care/nurses/resetPassword/' + userId,
    method: 'put'
  })
}

// 查询护理人员所有列表
export function listAllNurses(query) {
  return request({
    url: '/care/nurses/listAll',
    method: 'get',
    params: query
  })
}

// 查询当前公司所有的护理人列表
export function listCompanyNurses(query) {
  return request({
    url: '/care/nurses/listCompanyNurses',
    method: 'get',
    params: query
  })
}

